package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import java.math.BigInteger;

public class PKIStatusInfo extends ASN1Encodable {
   DERInteger status;
   PKIFreeText statusString;
   DERBitString failInfo;

   public static PKIStatusInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static PKIStatusInfo getInstance(Object obj) {
      if (obj instanceof PKIStatusInfo) {
         return (PKIStatusInfo)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new PKIStatusInfo((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public PKIStatusInfo(ASN1Sequence seq) {
      this.status = DERInteger.getInstance(seq.getObjectAt(0));
      this.statusString = null;
      this.failInfo = null;
      if (seq.size() > 2) {
         this.statusString = PKIFreeText.getInstance(seq.getObjectAt(1));
         this.failInfo = DERBitString.getInstance(seq.getObjectAt(2));
      } else if (seq.size() > 1) {
         DEREncodable seq1;
         if ((seq1 = seq.getObjectAt(1)) instanceof DERBitString) {
            this.failInfo = DERBitString.getInstance(seq1);
         } else {
            this.statusString = PKIFreeText.getInstance(seq1);
         }
      }

   }

   public PKIStatusInfo(int status) {
      PKIStatusInfo var10000 = this;
      super();
      DERInteger var2;
      var2 = new DERInteger.<init>(status);
      var10000.status = var2;
   }

   public PKIStatusInfo(int status, PKIFreeText statusString) {
      PKIStatusInfo var10000 = this;
      PKIStatusInfo var10001 = this;
      super();
      DERInteger var3;
      var3 = new DERInteger.<init>(status);
      var10001.status = var3;
      var10000.statusString = statusString;
   }

   public PKIStatusInfo(int status, PKIFreeText statusString, PKIFailureInfo failInfo) {
      PKIStatusInfo var10000 = this;
      PKIStatusInfo var10001 = this;
      PKIStatusInfo var10002 = this;
      super();
      DERInteger var4;
      var4 = new DERInteger.<init>(status);
      var10002.status = var4;
      var10001.statusString = statusString;
      var10000.failInfo = failInfo;
   }

   public BigInteger getStatus() {
      return this.status.getValue();
   }

   public PKIFreeText getStatusString() {
      return this.statusString;
   }

   public DERBitString getFailInfo() {
      return this.failInfo;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.status);
      PKIFreeText var2;
      if ((var2 = this.statusString) != null) {
         var1.add(var2);
      }

      DERBitString var3;
      if ((var3 = this.failInfo) != null) {
         var1.add(var3);
      }

      return new DERSequence(var1);
   }
}
